<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>सम्पूर्ण माथि कुनै भन्दा छुट्याउनुहोस्</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>नोटिफिकेशन केन्द्र</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>सम्पूर्ण माथि कुनै भन्दा छुट्याउनुहोस्</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>लगाउनुको सिर्जना छुट्याउनुहोस्</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>लगाउनुको सिर्जना लगाउनुहोस्</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>नोटिफिकेशन सेटिंग</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>अब तयार</translation>
    </message>
</context>
</TS>